## DETECT WHICH OBJS INTERSECT BBOX OF COLLISION OBJ OVER TIME
# On each frame, compares bounding box of each objects in list
# to the bounding box of collision object
# Adds all intersecting objects to list and display layer

## Written by Jessie Amadio
## Update: Dec 1st, 2014

import maya.cmds as cmds

def bboxDetect():
    hitList = []

    cmds.currentTime(1.0)
    frame = cmds.currentTime(q=True)
    endFrame = (cmds.playbackOptions(maxTime=True, q=True) + 1)

    objects = cmds.ls('objects*')

    while frame < endFrame:

        colBBox = cmds.exactWorldBoundingBox( 'collisionObjectGeo');

        xMinCol = colBBox[0]
        xMaxCol = colBBox[3]

        yMinCol = colBBox[1]
        yMaxCol = colBBox[4]

        zMinCol = colBBox[2]
        zMaxCol = colBBox[5]


        for obj in objects:
            bbox = cmds.exactWorldBoundingBox(obj);

            xMinObj = bbox[0]
            xMaxObj = bbox[3]

            yMinObj = bbox[1]
            yMaxObj = bbox[4]

            zMinObj = bbox[2]
            zMaxObj = bbox[5]

            xMinCheck = False
            xMaxCheck = False;
            zMinCheck = False;
            zMaxCheck = False;

            if xMinObj < xMinCol < xMaxObj:
                xMinCheck = True;

            if xMaxObj > xMaxCol > xMinObj:
                xMaxCheck = True;

            if zMinObj < zMinCol < zMaxObj:
                zMinCheck = True;

            if zMaxObj > zMaxCol > zMinObj:
                zMaxCheck = True;

            if (xMinCheck or xMaxCheck == True) and (zMinCheck or zMaxCheck == True):
                if obj not in hitList:
                    hitList.append(obj)

        frame += 1
        cmds.currentTime(frame)

    print hitList
    cmds.currentTime(1.0)

    #create display layer if it doesnt exist
    if cmds.objExists('collidingObjects'):
        pass
    else:
        cmds.createDisplayLayer(name="collidingObjects", number=1, nr=True)
        cmds.setAttr('collidingObjects.color', 9)

    #add colliding objects to display layer
    for i in hitList:
        cmds.editDisplayLayerMembers('collidingObjects', i)
        
bboxDetect()